from typing import Optional

import requests
import json
import pandas as pd
from mmproteo.utils import log, download as dl, formats
from mmproteo.utils.download import create_file_extension_filter
from mmproteo.utils.visualization import pretty_print_json

PRIDE_API_LIST_PROJECT_FILES = "https://www.ebi.ac.uk/pride/ws/archive/file/list/project/%s"
PRIDE_API_GET_PROJECT_SUMMARY = "https://www.ebi.ac.uk:443/pride/ws/archive/project/%s"


def get_project_link__list_project_files(project_name: str) -> str:
    return PRIDE_API_LIST_PROJECT_FILES % project_name


def get_project_link__get_project_summary(project_name: str) -> str:
    return PRIDE_API_GET_PROJECT_SUMMARY % project_name


def get_project_summary(project_name: str, logger: log.Logger = log.DUMMY_LOGGER) -> dict:
    """Get the project as a json and return it as a dataframe"""
    project_summary_link = get_project_link__get_project_summary(project_name)
    logger.info("Requesting project summary from " + project_summary_link)
    response = requests.get(project_summary_link)
    logger.debug("Received response from %s with length of %d bytes" % (project_summary_link, len(response.text)))
    response = json.loads(response.text)
    logger.info("Received project summary for project \"%s\"" % project_name)
    return response


def info(pride_project: str, logger: log.Logger = log.DUMMY_LOGGER) -> str:
    summary_dict = get_project_summary(project_name=pride_project, logger=logger)
    return pretty_print_json(summary_dict)


def get_project_files(project_name: str,
                      logger: log.Logger = log.DUMMY_LOGGER) -> pd.DataFrame:
    """Get the project as a json and return it as a dataframe"""
    project_files_link = get_project_link__list_project_files(project_name)
    logger.info("Requesting list of project files from " + project_files_link)
    response = requests.get(project_files_link)
    logger.debug("Received response from %s with length of %d bytes" % (project_files_link, len(response.text)))
    files_dict = json.loads(response.text)
    files_df = pd.DataFrame(pd.json_normalize(files_dict['list']))
    logger.info("Received list of %d project files" % len(files_df))
    return files_df


def download(project_name: str, logger: log.Logger = log.DUMMY_LOGGER, **kwargs) -> pd.DataFrame:
    project_files = get_project_files(project_name=project_name, logger=logger)
    return dl.download(project_files, logger=logger, **kwargs)


def filter_files(files_df: pd.DataFrame,
                 file_extensions: Optional[set] = None,
                 max_num_files: Optional[int] = None,
                 sort: bool = True,
                 logger: log.Logger = log.DUMMY_LOGGER) -> pd.DataFrame:
    if file_extensions is None or len(file_extensions) == 0:
        logger.debug("Skipping file extension filtering")
        filtered_files = files_df
    else:
        required_file_extensions = file_extensions
        optional_file_extensions = formats.get_extractable_file_extensions()

        required_file_extensions_list_str = "\", \"".join(required_file_extensions)
        optional_file_extensions_list_str = "\", \"".join(optional_file_extensions)
        if len(optional_file_extensions_list_str) > 0:
            optional_file_extensions_list_str = '"' + optional_file_extensions_list_str + '"'
        logger.info("Filtering repository files based on the following required file extensions [\"%s\"] and the "
                    "following optional file extensions [%s]" % (required_file_extensions_list_str,
                                                                 optional_file_extensions_list_str))

        file_extension_filter = create_file_extension_filter(required_file_extensions, optional_file_extensions)
        filtered_files = files_df[files_df.fileName.apply(file_extension_filter)]

        logger.debug("File extension filtering resulted in %d valid file names" % len(filtered_files))

    if sort:
        # sort, such that files with same prefixes but different extensions come in pairs
        sorted_files = filtered_files.sort_values(by='fileName')
    else:
        sorted_files = filtered_files

    if max_num_files is None or max_num_files == 0:
        limited_files = sorted_files
    else:
        limited_files = sorted_files[:max_num_files]

    return limited_files


def list_files(project_name: str,
               file_extensions: Optional[set] = None,
               logger: log.Logger = log.DUMMY_LOGGER) -> pd.DataFrame:
    project_files = get_project_files(project_name=project_name, logger=logger)
    return filter_files(files_df=project_files, file_extensions=file_extensions, sort=False, logger=logger)



import os


def ensure_dir_exists(directory):
    """Ensure the existence of a given directory (path) by creating it/them if they do not exist yet."""
    if len(directory) == 0:
        return directory
    if not os.path.exists(directory) or not os.path.isdir(directory):
        os.makedirs(directory)
    return directory


def deduplicate_list(lst: list) -> list:
    already_inserted = set()
    deduplicated_list = []
    for e in lst:
        if e not in already_inserted:
            already_inserted.add(e)
        deduplicated_list.append(e)
    return deduplicated_list


def extract_dict_or_inner_element(elem):
    try:
        # skip one-element lists or sets,...
        while type(elem) != dict and len(elem) == 1:
            elem = next(iter(elem))
    except:
        pass
    return elem


def flatten_dict(input_dict: dict, result_dict: dict = None, overwrite: bool = False) -> dict:
    if result_dict is None:
        result_dict = dict()

    dict_queue = [input_dict]

    while len(dict_queue) > 0:
        item = dict_queue[0]
        dict_queue = dict_queue[1:]

        for key, value in item.items():
            value = extract_dict_or_inner_element(value)

            if type(value) == dict:
                dict_queue.append(value)
                continue

            if not overwrite and key not in result_dict:
                result_dict[key] = value

    return result_dict



#!/usr/bin/python3
import sys
import os
import argparse
from .utils import visualization, log, pride, utils

logger = log.DummyLogger(send_welcome=False)


class Config:
    command_str = "command"
    pride_project_str = "--pride-project"
    max_num_files_str = "--max-num-files"
    count_failed_files_str = "--count-failed-files"
    storage_dir_str = "--storage-dir"
    log_file_str = "--log-file"
    log_to_stdout_str = "--log-to-stdout"
    valid_file_extensions_str = "--valid-file-extensions"
    no_skip_existing_str = "--no-skip-existing"
    no_extract_str = "--no-extract"
    verbose_str = "--verbose"
    shown_columns_str = "--shown-columns"

    def __init__(self):
        self.pride_project = None
        self.max_num_files = None
        self.count_failed_files = None
        self.storage_dir = None
        self.log_file = None
        self.log_to_stdout = None
        self.valid_file_extensions = None
        self.skip_existing = None
        self.extract = None
        self.verbose = None
        self.shown_columns = None
        self.commands = None

    def parse_arguments(self):
        parser = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter)

        parser.add_argument(Config.command_str,
                            nargs='+',
                            choices=list(COMMAND_DISPATCHER.keys()),
                            help="the list of actions to be performed on the repository. " +
                                 "Every action can only occur once. " +
                                 "Duplicates are dropped after the first occurrence.")
        parser.add_argument("-p", Config.pride_project_str,
                            help="the name of the PRIDE project, e.g. 'PXD010000' " +
                                 "from 'https://www.ebi.ac.uk/pride/ws/archive/peptide/list/project/PXD010000'." +
                                 "For some commands, this parameter is required.")
        parser.add_argument("-n", Config.max_num_files_str,
                            default=0,
                            type=int,
                            help="the maximum number of files to be downloaded. Set it to '0' to download all files.")
        parser.add_argument(Config.count_failed_files_str,
                            action="store_false",
                            help="Count failed files and do not just skip them. " +
                                 "This is relevant for the max-num-files parameter.")
        parser.add_argument("-d", Config.storage_dir_str,
                            default=os.path.join(".", "pride"),
                            help="the name of the directory, in which the downloaded files and the log file will be "
                                 "stored.")
        parser.add_argument("-l", Config.log_file_str,
                            default="downloader.log",
                            help="the name of the log file, relative to the download directory.")
        parser.add_argument(Config.log_to_stdout_str,
                            action="store_true",
                            help="Log to stdout instead of stderr.")
        parser.add_argument("-t", Config.valid_file_extensions_str,
                            default="",
                            help="a list of comma-separated allowed file extensions to filter files for. " +
                                 "An empty list deactivates filtering. "
                                 "Capitalization does not matter.")
        parser.add_argument("-e", Config.no_skip_existing_str,
                            action="store_true",
                            help="Do not skip existing files.")
        parser.add_argument("-x", Config.no_extract_str,
                            action="store_true",
                            help="Do not try to extract downloaded files.")
        # store_true turns "verbose" into a flag:
        # The existence of "verbose" equals True, the lack of existence equals False
        parser.add_argument("-v", Config.verbose_str,
                            action="store_true",
                            help="Increase output verbosity to debug level.")
        parser.add_argument(Config.shown_columns_str,
                            default="",
                            help="a list of comma-separated column names. Some commands show their results as tables, "
                                 "so their output columns will be limited to those in this list. An empty list "
                                 "deactivates filtering. Capitalization matters.")

        args = parser.parse_args()

        self.pride_project = args.pride_project
        self.max_num_files = args.max_num_files
        self.count_failed_files = args.count_failed_files
        self.storage_dir = args.storage_dir
        self.log_file = args.log_file
        self.log_to_stdout = args.log_to_stdout
        self.valid_file_extensions = {ext.lower() for ext in args.valid_file_extensions.split(",") if len(ext) > 0}
        self.skip_existing = (not args.no_skip_existing)
        self.extract = (not args.no_extract)
        self.verbose = args.verbose
        self.shown_columns = [col for col in args.shown_columns.split(",") if len(col) > 0]

        self.commands = utils.deduplicate_list(args.command)

    def require_pride_project(self):
        assert self.pride_project is not None, Config.pride_project_str + " is missing"
        assert len(self.pride_project) > 0, Config.pride_project_str + " must not be empty"

    def validate_arguments(self):
        assert len(self.storage_dir) > 0, "download-dir must not be empty"
        assert len(self.log_file) > 0, "log-file must not be empty"

    def check(self):
        utils.ensure_dir_exists(self.storage_dir)


def set_logger(config: Config):
    global logger
    if config.log_to_stdout:
        log_to_std = sys.stdout
    else:
        log_to_std = sys.stderr

    logger = log.create_logger(name="PRIDE_Downloader",
                               log_dir=config.storage_dir,
                               filename=config.log_file,
                               verbose=config.verbose,
                               log_to_std=log_to_std)


def run_download(config: Config):
    downloaded_files = pride.download(project_name=config.pride_project,
                                      logger=logger,
                                      valid_file_extensions=config.valid_file_extensions,
                                      max_num_files=config.max_num_files,
                                      download_dir=config.storage_dir,
                                      skip_existing=config.skip_existing,
                                      extract=config.extract,
                                      count_failed_files=config.count_failed_files)
    visualization.print_df(df=downloaded_files,
                           max_num_files=None,
                           shown_columns=config.shown_columns,
                           logger=logger)


def validate_download(config: Config):
    config.require_pride_project()

    if len(config.valid_file_extensions) != 0 and config.max_num_files % len(config.valid_file_extensions) != 0:
        logger.info(
            "Warning: max-num-files should be a multiple of the number of valid_file_extensions to make sure that "
            "files that belong together are also downloaded together")


def run_info(config: Config):
    project_info = pride.info(pride_project=config.pride_project, logger=logger)
    print(project_info)


def validate_info(config: Config):
    config.require_pride_project()


def run_ls(config: Config):
    project_files = pride.list_files(project_name=config.pride_project,
                                     file_extensions=config.valid_file_extensions,
                                     logger=logger)
    visualization.print_df(df=project_files,
                           max_num_files=config.max_num_files,
                           shown_columns=config.shown_columns,
                           logger=logger)


def validate_ls(config: Config):
    config.require_pride_project()


COMMAND_DISPATCHER = {
    "download": {
        "handler": run_download,
        "validator": validate_info,
    },
    "info": {
        "handler": run_info,
        "validator": validate_info,
    },
    "ls": {
        "handler": run_ls,
        "validator": validate_info,
    }
}


def get_command_config(command: str):
    command_config = COMMAND_DISPATCHER.get(command)
    if command_config is None:
        raise NotImplementedError("%s is no known command")
    return command_config


def dispatch_commands(config: Config):
    command_configs = [get_command_config(command) for command in config.commands]

    try:
        for command_config in command_configs:
            command_config["validator"](config)
    except Exception as e:
        logger.error(str(e))
        return

    for command_config in command_configs:
        command_config["handler"](config)


def main(config: Config = None):
    if config is None:
        config = Config()
        config.parse_arguments()
    config.validate_arguments()
    config.check()
    set_logger(config)

    dispatch_commands(config)


if __name__ == '__main__':
    main()



import json

from mmproteo.utils import log
from typing import Optional, List
import pandas as pd

pd.set_option('display.max_columns', None)
pd.set_option('display.max_rows', None)
pd.set_option('display.max_colwidth', None)
pd.set_option('display.width', None)


def print_df(df: pd.DataFrame,
             max_num_files: Optional[int] = None,
             shown_columns: Optional[List[str]] = None,
             logger: log.Logger = log.DUMMY_LOGGER):
    if max_num_files is not None and max_num_files != 0:
        df = df[:max_num_files]
        logger.info("Showing only the top %d entries because of the max_num_files parameter" % max_num_files)
    if shown_columns is not None and shown_columns != []:
        columns = [col for col in shown_columns if col in df.columns]
        df = df[columns]
        logger.info("Limiting the shown columns according to the shown_columns parameter")
    print(df)


def pretty_print_json(dic: dict) -> str:
    return json.dumps(dic, indent=4)


from mmproteo.utils import utils


def test_extract_dict_or_inner_element():
    a = dict()
    assert a == utils.extract_dict_or_inner_element(a)
    assert a == utils.extract_dict_or_inner_element([a])

    b = [1, 2]
    assert b == utils.extract_dict_or_inner_element(b)
    assert b == utils.extract_dict_or_inner_element([[b]])


def test_flatten_dict():
    a = {3: 4, 4: [4], 5: {5}}
    b = {0: 0, 1: [1], 2: {2}, 3: 3, "a": a}

    res = {0: 0, 1: 1, 2: 2, 3: 3, 4: 4, 5: 5}
    assert res == utils.flatten_dict(b)



from typing import Optional, List, Callable
import pandas as pd
import wget
import os
from mmproteo.utils import log, formats, pride


def create_file_extension_filter(required_file_extensions: set,
                                 optional_file_extensions: Optional[set] = None) -> Callable[[str], bool]:
    if optional_file_extensions is not None:
        assert len(required_file_extensions.intersection(optional_file_extensions)) == 0, "Extension sets must be " \
                                                                                          "distinct."

    def filter_file_extension(filename: str):
        filename = filename.lower()
        extensions = reversed(filename.split("."))
        extension = next(extensions)
        if optional_file_extensions is not None:
            if extension in optional_file_extensions:
                extension = next(extensions, extension)
        return extension in required_file_extensions

    return filter_file_extension


def download_file(link: str, skip_existing: bool = True) -> (str, str):
    filename = link.split("/")[-1]
    downloaded_file_name = None

    found_downloaded_file = False
    found_extracted_file = False

    skip_reason = None

    if skip_existing:
        if os.path.isfile(filename):
            found_downloaded_file = True
            downloaded_file_name = filename
            skip_reason = 'file "%s" already exists' % downloaded_file_name

        extracted_file_name, extension = formats.separate_archive_extension(filename)
        file_is_extractable = len(extension) > 0

        if file_is_extractable:
            # gunzip deletes the archive file after extraction, other programmes keep it
            if os.path.isfile(extracted_file_name):
                found_extracted_file = True
                skip_reason = 'extracted file "%s" already exists' % extracted_file_name

    if not (skip_existing and (found_downloaded_file or found_extracted_file)):
        downloaded_file_name = wget.download(link)  # might raise an EXCEPTION

    return downloaded_file_name, skip_reason


def download_files(links: List[str],
                   skip_existing: bool = True,
                   count_failed_files: bool = False,
                   logger: log.Logger = log.DUMMY_LOGGER) -> List[str]:
    num_files = len(links)

    logger.info("Downloading %d files" % num_files)

    files_downloaded_count = 0
    files_processed = 1

    downloaded_files_names = []

    for link in links:
        logger.info("Downloading file %d/%d: %s" % (files_processed, num_files, link))

        try:
            downloaded_file_name, skip_reason = download_file(link, skip_existing)
        except Exception as e:
            downloaded_file_name, skip_reason = None, None
            logger.info('Failed to download file %d/%d ("%s") because of "%s"' %
                        (files_processed, num_files, link, e))
        downloaded_file_available = downloaded_file_name is not None
        download_skipped = skip_reason is not None
        download_succeeded = downloaded_file_available or download_skipped

        if download_succeeded:
            if download_skipped:
                logger.info('Skipped download, because ' + skip_reason)
            else:
                files_downloaded_count += 1
                logger.info('Downloaded file %d/%d: "%s"' % (files_processed, num_files, link))

        downloaded_files_names.append(downloaded_file_name)

        if download_succeeded or count_failed_files:
            files_processed += 1

    logger.info("Finished downloading %d files" % files_downloaded_count)
    return downloaded_files_names


def extract_files(filenames: List[Optional[str]],
                  skip_existing: bool = True,
                  logger: log.Logger = log.DUMMY_LOGGER) -> List[Optional[str]]:
    return [formats.extract_file_if_possible(filename, skip_existing=skip_existing, logger=logger)
            for filename in filenames]


def download(project_files: pd.DataFrame,
             valid_file_extensions: set,
             max_num_files: Optional[int],
             download_dir: str,
             skip_existing: bool,
             extract: bool,
             count_failed_files: bool,
             logger: log.Logger = log.DUMMY_LOGGER) -> pd.DataFrame:
    filtered_files = pride.filter_files(files_df=project_files,
                                        file_extensions=valid_file_extensions,
                                        max_num_files=max_num_files,
                                        logger=logger)
    initial_directory = os.getcwd()
    os.chdir(download_dir)

    filtered_files['downloaded_files'] = download_files(links=filtered_files.downloadLink,
                                                        skip_existing=skip_existing,
                                                        count_failed_files=count_failed_files,
                                                        logger=logger)

    if extract:
        filtered_files['extracted_files'] = extract_files(filenames=filtered_files.downloaded_files,
                                                          skip_existing=skip_existing,
                                                          logger=logger)

    os.chdir(initial_directory)
    return filtered_files



import os
import sys
import logging
from mmproteo.utils.utils import ensure_dir_exists

LOG_FORMAT = '%(asctime)s - %(name)s: %(message)s'
DEFAULT_LOG_SUFFIX = '.log'


class Logger:
    def __init__(self, logger):
        self.logger = logger

    def info(self, msg: str = ""):
        self.logger.info(msg)

    def debug(self, msg: str = ""):
        self.logger.debug(msg)

    def error(self, msg: str = ""):
        self.info("ERROR: " + msg)


class DummyLogger(Logger):
    def __init__(self, send_welcome=True):
        super().__init__(None)
        if send_welcome:
            self.info("Printing to Stdout")

    def info(self, msg: str = ""):
        print("INFO: " + msg)

    def debug(self, msg: str = ""):
        print("DEBUG: " + msg)

    def error(self, msg: str = ""):
        print("ERROR: " + msg)


def create_logger(name: str,
                  level=None,
                  verbose: bool = None,
                  filename: str = None,
                  log_dir: str = ".",
                  log_to_std=sys.stderr):
    if verbose is not None:
        assert level is None, "level and verbose are exclusive parameters"
        if verbose:
            level = logging.DEBUG
        else:
            level = logging.INFO
    else:
        assert level is not None, "either level or verbose must be given as parameter"
    try:
        assert name is not None
        assert type(name) == str
        if filename is None:
            filename = name + DEFAULT_LOG_SUFFIX
        if log_dir is not None:
            filename = os.path.join(log_dir, filename)
        logger = logging.getLogger(name)
        logger.setLevel(level)

        formatter = logging.Formatter(LOG_FORMAT)

        # log to file
        dir_name = os.path.dirname(filename)
        ensure_dir_exists(dir_name)
        fh = logging.FileHandler(filename)
        fh.setFormatter(formatter)
        fh.setLevel(level)
        logger.addHandler(fh)

        if log_to_std is not None:
            oh = logging.StreamHandler(log_to_std)
            oh.flush = sys.stdout.flush
            oh.setFormatter(formatter)
            oh.setLevel(level)
            logger.addHandler(oh)

            logger.info("Logging to %s and to file %s" % (log_to_std.name, filename))
        else:
            logger.info("Logging to file %s" % filename)

        return Logger(logger)
    except Exception as e:
        print("Error: Failed to create logger", str(name))
        print(e)
        print("Returned print-only dummy logger")
        logger = DummyLogger()
        return logger


DUMMY_LOGGER = DummyLogger(send_welcome=False)



from typing import Optional, Set

from pyteomics import mgf, mzid
import pandas as pd
import json
import os
from mmproteo.utils import log, utils


def iter_entries(iterator, logger: log.Logger = log.DUMMY_LOGGER) -> list:
    logger.debug(type(iterator))
    entries = list(iterator)
    logger.debug("Length: %d" % len(entries))
    if len(entries) > 0:
        logger.debug("Example:")
        logger.debug()
        try:
            logger.debug(json.dumps(entries[0], indent=4))
        except TypeError:
            logger.debug(entries[0])
    return entries


def read_mgf(filename: str, logger: log.Logger = log.DUMMY_LOGGER) -> pd.DataFrame:
    entries = iter_entries(mgf.read(filename), logger=logger)
    extracted_entries = [utils.flatten_dict(entry) for entry in entries]
    return pd.DataFrame(data=extracted_entries)


def extract_features_from_mzid_entry(entry: dict) -> dict:
    result = utils.flatten_dict(entry)

    try:
        utils.flatten_dict(result.pop('SpectrumIdentificationItem')[0], result)
    except KeyError:
        pass

    try:
        utils.flatten_dict(result.pop('PeptideEvidenceRef')[0], result)
    except KeyError:
        pass

    return result


def read_mzid(filename: str, logger: log.Logger = log.DUMMY_LOGGER) -> pd.DataFrame:
    entries = iter_entries(mzid.read(filename), logger=logger)
    extracted_entries = [extract_features_from_mzid_entry(entry) for entry in entries]
    return pd.DataFrame(data=extracted_entries)


def read(filename: str, logger: log.Logger = log.DUMMY_LOGGER) -> pd.DataFrame:
    if filename.endswith('.mgf'):
        df = read_mgf(filename, logger=logger)
    elif filename.endswith('.mzid'):
        df = read_mzid(filename, logger=logger)
    else:
        raise NotImplementedError
    return df


FILE_EXTRACTION_CONFIG = {
    "gz": {
        "command": 'gunzip "%s"'
    },
    "zip": {
        "command": 'unzip "%s"'
    }}


def get_extractable_file_extensions() -> Set[str]:
    return set(FILE_EXTRACTION_CONFIG.keys())


def separate_archive_extension(filename: str) -> (str, str):
    lower_filename = filename.lower()
    longest_extension = ""
    for ext in FILE_EXTRACTION_CONFIG.keys():
        if lower_filename.endswith(ext) and len(longest_extension) < len(ext):
            longest_extension = ext

    real_filename = filename[:len(filename) - len(longest_extension)]
    return real_filename, longest_extension


def extract_file_if_possible(filename: Optional[str],
                             skip_existing: bool = True,
                             logger: log.Logger = log.DUMMY_LOGGER) -> Optional[str]:
    if filename is None:
        return None

    _, file_ext = separate_archive_extension(filename.lower())
    if len(file_ext) > 0:
        return filename

    extraction_command = FILE_EXTRACTION_CONFIG[file_ext]["command"] % filename
    new_filename = filename[:-(len(file_ext) + 1)]

    if skip_existing and os.path.isfile(new_filename):
        logger.info('Skipping extraction, because "%s" already exists' % new_filename)
        return new_filename

    logger.info("Extracting downloaded file using '%s'" % extraction_command)
    return_code = os.system(extraction_command)
    if return_code == 0:
        logger.info("Extracted downloaded file")
    else:
        logger.info('Failed extracting downloaded file "%s" (return code = %d)' % (filename, return_code))

    return new_filename



#!/usr/bin/python3

from mmproteo.utils import pride
import pandas as pd

SAMPLE_PROJECT = "PXD010000"


def store_info():
    with open("resources/" + SAMPLE_PROJECT + "_info.txt", "w") as file:
        file.write(pride.info(SAMPLE_PROJECT))


def test_info():
    with open("resources/" + SAMPLE_PROJECT + "_info.txt", "r") as file:
        expected_info = file.read()

    received_info = pride.info(SAMPLE_PROJECT)
    assert expected_info == received_info


def store_project_files():
    pride.get_project_files(SAMPLE_PROJECT).to_parquet("resources/" + SAMPLE_PROJECT + "_files.parquet")


def test_get_project_files():
    expected_files = pd.read_parquet("resources/" + SAMPLE_PROJECT + "_files.parquet")
    received_files = pride.get_project_files(SAMPLE_PROJECT)
    pd._testing.assert_frame_equal(expected_files, received_files, check_exact=True)


def store_raw_project_files():
    pride.list_files(SAMPLE_PROJECT, {"raw"}).to_parquet("resources/" + SAMPLE_PROJECT + "_files_raw.parquet")


def store_mgf_mzid_project_files():
    pride.list_files(SAMPLE_PROJECT, {"mgf", "mzid"})\
        .to_parquet("resources/" + SAMPLE_PROJECT + "_files_mgf_mzid.parquet")


def test_list_files():
    expected_files = pd.read_parquet("resources/" + SAMPLE_PROJECT + "_files.parquet")
    received_files = pride.list_files(SAMPLE_PROJECT)
    pd._testing.assert_frame_equal(expected_files, received_files, check_exact=True)


def test_list_files_raw():
    expected_files = pd.read_parquet("resources/" + SAMPLE_PROJECT + "_files_raw.parquet")
    received_files = pride.list_files(SAMPLE_PROJECT, {"raw"})
    pd._testing.assert_frame_equal(expected_files, received_files, check_exact=True)


def test_list_files_mgf_mzid():
    expected_files = pd.read_parquet("resources/" + SAMPLE_PROJECT + "_files_mgf_mzid.parquet")
    received_files = pride.list_files(SAMPLE_PROJECT, {"mgf", "mzid"})
    pd._testing.assert_frame_equal(expected_files, received_files, check_exact=True)


if __name__ == '__main__':
    store_info()
    store_project_files()
    store_raw_project_files()
    store_mgf_mzid_project_files()
